@@ -265,6 +265,10 @@ class DnlActiveCallSession(object):
         result = self._api_call('spamdb_ftc_search {}'.format(number)).decode('utf-8').strip()
         return result
 
+    def lrn_search(self, number):
+        result = self._api_call('lrn_search {}'.format(number)).decode('utf-8').strip()
+        return result
+
 
 def get_dnl_active_calls_session(ip, port):
     try:
