@@ -24,6 +24,7 @@ from api_dnl.view import DEFAULT_SECURITY, OperationErrorResponse
 import json
 from api_dnl.views.report import Report
 import uuid
+import requests
 
 def generate_uuid_str():
     return lambda: str(uuid.uuid4())
@@ -394,6 +395,20 @@ class ShakenStiSpConfCreate(DnlCreate):
         default_key = req.data.get("default_key") == "true"
         session = model.get_db().session
         try:
+            priv_key = req.data.get('priv_key')
+            if not ShakenStiSpConfResource.validate_priv_key(priv_key):
+                self.set_response(
+                    resp,
+                    responses.ValidationErrorResponse(data={'priv_key': 'bad value'})
+                )
+                return False
+            x5u = req.data.get('x5u')
+            if x5u is not None and not ShakenStiSpConfResource.validate_x5u(x5u):
+                self.set_response(
+                    resp,
+                    responses.ValidationErrorResponse(data={'x5u': 'bad value'})
+                )
+                return False
             if default_key:
                 sql = text("""
                     WITH reset AS (
@@ -458,6 +473,20 @@ class ShakenStiSpConfResource(DnlResource):
         object_id = kwargs['id']
         
         try:
+            priv_key = req.data.get('priv_key')
+            if priv_key and not self.validate_priv_key(priv_key):
+                self.set_response(
+                    resp,
+                    responses.ValidationErrorResponse(data={'priv_key': 'bad value'})
+                )
+                return False
+            x5u = req.data.get('x5u')
+            if x5u is not None and not self.validate_x5u(x5u):
+                self.set_response(
+                    resp,
+                    responses.ValidationErrorResponse(data={'x5u': 'bad value'})
+                )
+                return False
             if default_key:
                 sql = text("""
                     WITH reset AS (
@@ -506,6 +535,31 @@ class ShakenStiSpConfResource(DnlResource):
             self.set_response(resp, OperationErrorResponse(e))
             return False
 
+    @staticmethod
+    def validate_priv_key(priv_key):
+        try:
+            if 'BEGIN EC PARAMETERS' in priv_key and 'END EC PARAMETERS' in priv_key and \
+                    'BEGIN EC PRIVATE KEY' in priv_key and 'END EC PRIVATE KEY' in priv_key:
+                return True
+            else:
+                log.warning('Private key markers not found or invalid format')
+                return False
+        except Exception as e:
+            log.error('Error fetching priv key: {}'.format(str(e)))
+            return False
+
+    @staticmethod
+    def validate_x5u(x5u):
+        try:
+            if x5u.startswith('http') and x5u.endswith('.crt'):
+                return True
+            else:
+                log.warning('Certificate not valid. {}'.format(x5u))
+                return False
+        except Exception as e:
+            log.error('Error fetching certificate: {}'.format(str(e)))
+            return False
+
 
 class ShakenStiSpConfList(DnlList):
     scheme_class = ShakenStiSpConfSchemeGet
